import { jsonError } from "../../../common.js";

export async function onRequestDelete(context: RequestContext) {
  const { id } = context.data.body;

  if (
    typeof id !== "string" ||
    id.search(/\D/) ||
    id.length > 19 ||
    id.length < 17
  )
    return jsonError("Invalid ID", 400);

  await context.env.DATA.delete(`etmember_${id}`);
  await context.env.D1.prepare("DELETE FROM et_members WHERE id = ?;")
    .bind(id)
    .run();

  return new Response(null, {
    status: 204,
  });
}

export async function onRequestPost(context: RequestContext) {
  const { id, name } = context.data.body;

  if (
    typeof id !== "string" ||
    id.match(/\D/) ||
    id.length > 19 ||
    id.length < 17
  )
    return jsonError("Invalid user ID", 400);

  if (typeof name !== "string" || !name.length || name.length > 32)
    return jsonError("Invalid name", 400);

  if (await context.env.DATA.get(`etmember_${id}`))
    return jsonError("User is already a member", 400);

  const createdAt = Date.now();
  const addingUser = context.data.current_user.id;

  await context.env.DATA.put(
    `etmember_${id}`,
    JSON.stringify({
      created_at: createdAt,
      created_by: addingUser,
      name,
    }),
  );
  await context.env.D1.prepare(
    "INSERT INTO et_members (created_at, created_by, id, name) VALUES (?, ?, ?, ?);",
  )
    .bind(createdAt, addingUser, id, name)
    .run();

  return new Response(null, {
    status: 204,
  });
}
